@@ -1,3 +1,4 @@
+#' @export 
 `addSpatial` <- function(map, raggedArray=NULL, effect=NULL, prefix=NULL) {
 	# find the name of the effect if it isn't specified
     if(is.null(effect)) {
@@ -139,8 +140,8 @@ spatialBugs.matrix=function(map, raggedArray=NULL, effect=NULL, prefix=NULL, reg
 	}
 	
 	# add to ragged array
-	raggedArray[[paste("xSpatial", effect, sep="")]] = map[,"x"]
-	raggedArray[[paste("ySpatial", effect, sep="")]] = map[,"y"]
+	raggedArray[[paste("xSpatial", effect, sep="")]] = map[,"x"] - mean(map[,'x'])
+	raggedArray[[paste("ySpatial", effect, sep="")]] = map[,"y"] - mean(map[,"y"])
 	
 	raggedArray[[paste("N", effect, "Spatial", sep="")]] = dim(map)[1]
 
