@@ -1,3 +1,4 @@
+#' @export
 glmmBUGS <- function (formula, data, effects, modelFile = "model.txt", 
 			initFile = "getInits.R", 
 		family = c("bernoulli", "binomial", "poisson", "gaussian"), 
@@ -9,7 +10,7 @@ glmmBUGS <- function (formula, data, effects, modelFile = "model.txt",
 )
 {
     data = getDesignMatrix(formula, data, effects)
-    data = na.omit(data)
+    data = stats::na.omit(data)
     covariates = attributes(data)$covariates
     observations = attributes(data)$response
     
